@@ -345,7 +345,7 @@ GitStats <- R6::R6Class(
                                progress) {
       private$check_for_host()
       args_list <- list(
-        "file_pattern" = pattern,
+        "file_pattern" = pattern %||% "",
         "depth" = depth
       )
       trigger <- private$trigger_pulling(
@@ -423,50 +423,6 @@ GitStats <- R6::R6Class(
       return(release_logs)
     },
 
-    get_repos_with_R_packages = function(packages,
-                                         only_loading = FALSE,
-                                         split_output = FALSE,
-                                         cache = TRUE,
-                                         verbose = TRUE) {
-      private$check_for_host()
-      if (is.null(packages)) {
-        cli::cli_abort("You need to define at least one `package_name`.", call = NULL)
-      }
-      args_list <- list(
-        "packages"     = packages,
-        "only_loading" = only_loading
-      )
-      trigger <- private$trigger_pulling(
-        storage   = "R_package_usage",
-        cache     = cache,
-        args_list = args_list,
-        verbose   = verbose
-      )
-      if (trigger) {
-        R_package_usage <- private$get_repos_with_R_packages_from_hosts(
-          packages = packages,
-          only_loading = only_loading,
-          split_output = split_output,
-          verbose = verbose
-        )
-        if ((!split_output && nrow(R_package_usage) > 0) ||
-              (split_output && any(purrr::map_lgl(R_package_usage, ~ nrow(.) > 0)))) {
-          R_package_usage <- private$set_object_class(
-            object = R_package_usage,
-            class = "gitstats_package_usage",
-            attr_list = args_list
-          )
-          private$save_to_storage(R_package_usage)
-        }
-      } else {
-        R_package_usage <- private$get_from_storage(
-          table = "R_package_usage",
-          verbose = verbose
-        )
-      }
-      return(R_package_usage)
-    },
-
     show_orgs = function() {
       purrr::map(private$hosts, function(host) {
         orgs <- host$.__enclos_env__$private$orgs
@@ -520,8 +476,7 @@ GitStats <- R6::R6Class(
       commits = NULL,
       users = NULL,
       files = NULL,
-      files_structure = NULL,
-      R_package_usage = NULL,
+      repos_trees = NULL,
       release_logs = NULL
     ),
 
@@ -895,7 +850,7 @@ GitStats <- R6::R6Class(
           }) |>
           purrr::list_rbind() |>
           dplyr::mutate(
-            githost = retrieve_platform(host$.__enclos_env__$private$api_url)
+            githost = retrieve_githost(host$.__enclos_env__$private$api_url)
           )
       }) |>
         purrr::list_rbind()
@@ -947,122 +902,6 @@ GitStats <- R6::R6Class(
         dplyr::as_tibble()
     },
 
-    # Pull information on package usage in a table form
-    get_repos_with_R_packages_from_hosts = function(packages,
-                                                    only_loading,
-                                                    split_output = FALSE,
-                                                    verbose = TRUE) {
-      packages_usage_list <- purrr::map(packages, function(package_name) {
-        if (!only_loading) {
-          repos_with_package_as_dependency <- private$get_R_package_as_dependency(
-            package_name = package_name,
-            verbose = verbose
-          )
-        } else {
-          repos_with_package_as_dependency <- NULL
-        }
-        repos_using_package <- private$get_R_package_loading(
-          package_name = package_name,
-          verbose = verbose
-        )
-        package_usage_table <- purrr::list_rbind(
-          list(
-            repos_with_package_as_dependency,
-            repos_using_package
-          )
-        )
-        if (nrow(package_usage_table) > 0) {
-          duplicated_repos <- package_usage_table$api_url[duplicated(package_usage_table$api_url)]
-          package_usage_table <- package_usage_table[!duplicated(package_usage_table$api_url), ]
-          package_usage_table <- package_usage_table %>%
-            dplyr::mutate(
-              package_usage = ifelse(api_url %in% duplicated_repos, "import, library", package_usage)
-            )
-          package_usage_table <- dplyr::mutate(
-            package_usage_table,
-            package = package_name,
-            repo_fullname = paste0(organization, "/", repo_name)
-          ) |>
-            dplyr::relocate(
-              package, package_usage,
-              .before = repo_id
-            ) |>
-            dplyr::relocate(
-              repo_fullname,
-              .after = repo_id
-            )
-        }
-        return(package_usage_table)
-      })
-      if (split_output) {
-        packages_usage_result <- purrr::set_names(packages_usage_list, packages)
-        if (all(purrr::map_lgl(packages_usage_result, ~ nrow(.) == 0)) && verbose) {
-          cli::cli_alert_warning(
-            cli::col_yellow(
-              "No usage of R packages found."
-            )
-          )
-        }
-      } else {
-        packages_usage_result <- purrr::list_rbind(packages_usage_list)
-        if (nrow(packages_usage_result) == 0 && verbose) {
-          cli::cli_alert_warning(
-            cli::col_yellow(
-              "No usage of R packages found."
-            )
-          )
-        }
-      }
-      return(packages_usage_result)
-    },
-
-    # Search repositories with `library(package_name)` in code blobs.
-    get_R_package_loading = function(package_name, verbose) {
-      if (verbose) {
-        cli::cli_alert("Checking where [{package_name}] is loaded from library...")
-      }
-      package_usage_phrases <- c(
-        glue::glue("library({package_name})"),
-        glue::glue("require({package_name})")
-      )
-      repos_using_package <- purrr::map(package_usage_phrases, ~ {
-        repos_using_package <- private$get_repos_from_hosts(
-          with_code = .,
-          force_orgs = FALSE,
-          output = "table",
-          verbose = FALSE,
-          progress = FALSE
-        )
-        if (!is.null(repos_using_package) && nrow(repos_using_package) > 0) {
-          repos_using_package$package_usage <- "library"
-        }
-        return(repos_using_package)
-      }) %>%
-        purrr::list_rbind() %>%
-        unique()
-      return(repos_using_package)
-    },
-
-    # @description Search repositories with `package_name` in DESCRIPTION and NAMESPACE files.
-    # @param package_name Name of a package.
-    get_R_package_as_dependency = function(package_name, verbose) {
-      if (verbose) {
-        cli::cli_alert("Checking where [{package_name}] is used as a dependency...")
-      }
-      repos_with_package <- private$get_repos_from_hosts(
-        with_code = package_name,
-        in_files = c("DESCRIPTION", "NAMESPACE"),
-        output = "table",
-        verbose = FALSE,
-        progress = FALSE
-      )
-      if (nrow(repos_with_package) > 0) {
-        repos_with_package <- repos_with_package[!duplicated(repos_with_package$api_url), ]
-        repos_with_package$package_usage <- "import"
-      }
-      return(repos_with_package)
-    },
-
     # Add some user-friendly columns to repositories table
     add_stats_to_repos = function(repos_table) {
       if (nrow(repos_table > 0)) {
@@ -1078,7 +917,7 @@ GitStats <- R6::R6Class(
             ) |> round(2)
           ) |>
           dplyr::relocate(
-            organization, fullname, platform, repo_url, api_url, created_at,
+            organization, fullname, githost, repo_url, api_url, created_at,
             last_activity_at, last_activity,
             .after = repo_name
           )
@@ -1204,18 +1043,17 @@ GitStats <- R6::R6Class(
       if (!storage_name %in% c("repositories", "organizations")) {
         storage_attr <- switch(storage_name,
                                "repos_urls" = "type",
+                               "repos_trees" = "file_pattern",
                                "files" = "file_pattern",
                                "commits" = "date_range",
                                "issues" = "date_range",
                                "release_logs" = "date_range",
-                               "users" = "logins",
-                               "R_package_usage" = "packages")
+                               "users" = "logins")
         attr_data <- attr(storage_data, storage_attr)
         attr_name <- switch(storage_attr,
                             "type" = "type",
                             "file_pattern" = "file pattern",
                             "date_range" = "date range",
-                            "packages" = "packages",
                             "logins" = "logins")
         if (length(attr_data) > 1) {
           separator <- if (storage_attr == "date_range") {
